From: Christophe Romain
Date: Fri, 29 May 2009 00:27:26 +0000 (+0000)
Subject: make flat the default node plugin
X-Git-Tag: v2.1.0~18^2~319
X-Git-Url: https://granicus.if.org/sourcecode?a=commitdiff_plain;h=c27d6fddf4c14d0208833e0c22d795b6d739ec6a;p=ejabberd
make flat the default node plugin
SVN Revision: 2116
---
diff --git a/src/mod_pubsub/pubsub.hrl b/src/mod_pubsub/pubsub.hrl
index dc95e3378..b896d4614 100644
--- a/src/mod_pubsub/pubsub.hrl
+++ b/src/mod_pubsub/pubsub.hrl
@@ -62,7 +62,7 @@
%%% @type nodeType() = string().
%%% The nodeType is a string containing the name of the PubSub
%%% plugin to use to manage a given node. For example, it can be
-%%% "default", "collection" or "blog".
+%%% "flat", "hometree" or "blog".
%%% @type jid() = #jid{
%%% user = string(),
@@ -92,7 +92,7 @@
-record(pubsub_node, {nodeid,
id,
parent,
- type = "default",
+ type = "flat",
owners = [],
options = []
}).
diff --git a/src/mod_pubsub/mod_pubsub.erl b/src/mod_pubsub/mod_pubsub.erl
index d267eabdd..1c5f688b1 100644
--- a/src/mod_pubsub/mod_pubsub.erl
+++ b/src/mod_pubsub/mod_pubsub.erl
@@ -228,7 +228,7 @@ init([ServerHost, Opts]) ->
%% node_plugin. The 'node_' prefix is mandatory.
%% The modules are initialized in alphetical order and the list is checked
%% and sorted to ensure that each module is initialized only once.
%% See {@link node_default:init/1} for an example implementation.
init_plugins(Host, ServerHost, Opts) ->
TreePlugin = list_to_atom(?TREE_PREFIX ++
gen_mod:get_opt(nodetree, Opts, ?STDTREE)),
@@ -1563,7 +1563,7 @@ delete_node(Host, Node, Owner) ->
%% Node = pubsubNode()
%% From = jid()
%% JID = jid()
-%% @see node_default:subscribe_node/5
+%% @see node_hometree:subscribe_node/5
%% @doc Accepts or rejects subcription requests on a PubSub node.
%%There are several reasons why the subscription request might fail:
%%
@@ -3000,7 +3000,7 @@ select_type(ServerHost, Host, Node) ->
features() ->
[
%TODO "access-authorize", % OPTIONAL
- "access-open", % OPTIONAL this relates to access_model option in node_default
+ "access-open", % OPTIONAL this relates to access_model option in node_hometree
"access-presence", % OPTIONAL this relates to access_model option in node_pep
%TODO "access-roster", % OPTIONAL
"access-whitelist", % OPTIONAL
@@ -228,7 +228,7 @@ init([ServerHost, Opts]) ->
%% The modules are initialized in alphetical order and the list is checked
%% and sorted to ensure that each module is initialized only once.
-%% See {@link node_default:init/1} for an example implementation.
+%% See {@link node_hometree:init/1} for an example implementation.
init_plugins(Host, ServerHost, Opts) ->
TreePlugin = list_to_atom(?TREE_PREFIX ++